pub enum Error {
NoDefaultOutputDevice,
DefaultStreamConfigError(DefaultStreamConfigError),
BuildStreamError(BuildStreamError),
PlayStreamError(PlayStreamError),
}Available on crate feature
cpal only.Expand description
Errors that can occur when using the cpal backend.
Variants
NoDefaultOutputDevice
A default audio output device could not be determined.
DefaultStreamConfigError(DefaultStreamConfigError)
An error occurred when getting the default output configuration.
BuildStreamError(BuildStreamError)
An error occurred when building the audio stream.
PlayStreamError(PlayStreamError)
An error occurred when starting the audio stream.