Struct kira::dsp::Frame

source ·
pub struct Frame {
    pub left: f32,
    pub right: f32,
}
A stereo audio sample.

Fields

left: f32

The sample for the left channel.

right: f32

The sample for the right channel.

Implementations

source

impl Frame

source

pub const ZERO: Frame = _

A Frame with both the left and right samples set to 0.0.

source

pub fn new(left: f32, right: f32) -> Self

Creates a frame with the given left and right values.

source

pub fn from_mono(value: f32) -> Self

Creates a frame with both the left and right channels set to the same value.

source

pub fn panned(self, x: f32) -> Self

Pans a frame to the left or right.

An x of 0 represents a hard left panning, an x of 1 represents a hard right panning.

source

pub fn as_mono(self) -> Self

Returns the frame mixed down to mono.