pub struct Frame {
pub left: f32,
pub right: f32,
}Expand description
A stereo audio sample.
Fields
left: f32The sample for the left channel.
right: f32The sample for the right channel.
Implementations
sourceimpl Frame
impl Frame
sourcepub fn new(left: f32, right: f32) -> Self
pub fn new(left: f32, right: f32) -> Self
Creates a frame with the given left and right values.
sourcepub fn from_mono(value: f32) -> Self
pub fn from_mono(value: f32) -> Self
Creates a frame with both the left and right channels set to the same value.