pub struct ListenerInfo {
pub position: Vector3<f32>,
pub orientation: Quaternion<f32>,
pub previous_position: Vector3<f32>,
pub previous_orientation: Quaternion<f32>,
}Expand description
Information about a listener.
Fields
position: Vector3<f32>The position of the listener.
orientation: Quaternion<f32>The rotation of the listener.
previous_position: Vector3<f32>The position of the listener prior to the last update.
previous_orientation: Quaternion<f32>The rotation of the listener prior to the last update.
Implementations
Sourceimpl ListenerInfo
impl ListenerInfo
Sourcepub fn interpolated_position(self, amount: f32) -> Vector3<f32>
pub fn interpolated_position(self, amount: f32) -> Vector3<f32>
Returns the interpolated position between the previous and current position of the listener.
Sourcepub fn interpolated_orientation(self, amount: f32) -> Quaternion<f32>
pub fn interpolated_orientation(self, amount: f32) -> Quaternion<f32>
Returns the interpolated orientation between the previous and current orientation of the listener.