Struct kira::manager::AudioManager

source ·
pub struct AudioManager<B: Backend = DefaultBackend> { /* private fields */ }
Controls audio from gameplay code.

Implementations

source

impl<B: Backend> AudioManager<B>

source

pub fn new(settings: AudioManagerSettings<B>) -> Result<Self, B::Error>

Creates a new AudioManager.

Examples

Create an AudioManager using the DefaultBackend and the default settings:

use kira::manager::{AudioManager, AudioManagerSettings, backend::DefaultBackend};

let audio_manager = AudioManager::<DefaultBackend>::new(AudioManagerSettings::default())?;

Create an AudioManager with a reverb effect on the main mixer track:

use kira::{
	manager::{AudioManager, AudioManagerSettings, backend::DefaultBackend},
	track::{TrackBuilder, effect::reverb::ReverbBuilder},
};

let audio_manager = AudioManager::<DefaultBackend>::new(AudioManagerSettings {
	main_track_builder: TrackBuilder::new().with_effect(ReverbBuilder::new()),
	..Default::default()
})?;
source

pub fn play<D: SoundData>( &mut self, sound_data: D ) -> Result<D::Handle, PlaySoundError<D::Error>>

Plays a sound.

Examples
use kira::sound::static_sound::{StaticSoundData, StaticSoundSettings};

let sound_data = StaticSoundData::from_file("sound.ogg", StaticSoundSettings::default())?;
manager.play(sound_data)?;
source

pub fn add_sub_track( &mut self, builder: TrackBuilder ) -> Result<TrackHandle, AddSubTrackError>

Creates a mixer sub-track.

source

pub fn add_clock( &mut self, speed: impl Into<Value<ClockSpeed>> ) -> Result<ClockHandle, AddClockError>

Creates a clock.

Examples

let clock = manager.add_clock(ClockSpeed::TicksPerMinute(120.0))?;
source

pub fn add_spatial_scene( &mut self, settings: SpatialSceneSettings ) -> Result<SpatialSceneHandle, AddSpatialSceneError>

Creates a spatial scene.

source

pub fn add_modulator<Builder: ModulatorBuilder>( &mut self, builder: Builder ) -> Result<Builder::Handle, AddModulatorError>

Creates a modulator.

Examples
use kira::modulator::lfo::LfoBuilder;

let modulator = manager.add_modulator(LfoBuilder::new())?;
source

pub fn pause(&self, fade_out_tween: Tween) -> Result<(), CommandError>

Fades out and pauses all audio.

Examples

Pause audio immediately:

use kira::tween::Tween;

manager.pause(Tween::default())?;

Fade out audio for 3 seconds and then pause:

use kira::tween::Tween;
use std::time::Duration;

manager.pause(Tween {
	duration: Duration::from_secs(3),
	..Default::default()
})?;
source

pub fn resume(&self, fade_out_tween: Tween) -> Result<(), CommandError>

Resumes and fades in all audio.

Examples

Resume audio with a 3-second fade-in:

use kira::tween::Tween;
use std::time::Duration;

manager.resume(Tween {
	duration: Duration::from_secs(3),
	..Default::default()
})?;
source

pub fn main_track(&self) -> TrackHandle

Returns a handle to the main mixer track.

Examples

Use the main track handle to adjust the volume of all audio:

use kira::tween::Tween;

manager.main_track().set_volume(0.5, Tween::default())?;
source

pub fn state(&self) -> MainPlaybackState

Returns the current playback state of the audio.

source

pub fn sound_capacity(&self) -> usize

Returns the number of sounds that can be loaded at a time.

source

pub fn sub_track_capacity(&self) -> usize

Returns the number of mixer sub-tracks that can exist at a time.

source

pub fn clock_capacity(&self) -> usize

Returns the number of clocks that can exist at a time.

source

pub fn spatial_scene_capacity(&self) -> usize

Returns the number of spatial scenes that can exist at a time.

source

pub fn modulator_capacity(&self) -> usize

Returns the number of modulators that can exist at a time.

source

pub fn num_sounds(&self) -> usize

Returns the number of sounds that are currently loaded.

source

pub fn num_sub_tracks(&self) -> usize

Returns the number of mixer sub-tracks that currently exist.

source

pub fn num_clocks(&self) -> usize

Returns the number of clocks that currently exist.

source

pub fn num_spatial_scenes(&self) -> usize

Returns the number of spatial scenes that currently exist.

source

pub fn num_modulators(&self) -> usize

Returns the number of modulators that currently exist.

source

pub fn backend_mut(&mut self) -> &mut B

Returns a mutable reference to this manager’s backend.